// Class: EnvPlotter
//
// Author: Your Name Here
//
// License Information:
//   This class is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation.
//
//   This class is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.

import java.awt.Color;

/**
 *  Environment-Based Applications:<br>
 *
 *    The EnvPlotter class provides methods for drawing in
 *    an environment by placing color blocks in its cells.
 *    Each drawing method should take a Color object as a
 *    parameter (the color with which to draw), and should
 *    have a void return type.  (This restriction allows the
 *    EnvPlotterGUI to recognize drawing methods, for which
 *    it automatically generates buttons.)
 *
 *  @author Your Name (based on a template provided by Alyce Brady)
 *  @version 1 January 2003
 **/

public class EnvPlotter
{
    // Instance Variables: Encapsulated data for EACH EnvPlotter object
    private BoundedEnv theEnv = null;
    private EnvPlotterGUI display = null;

  // constructors and initialization

    /** Constructs an object that draws in the specified environment.
     *      @param env the environment in which to draw
     *      @param disp an object that knows how to display an environment
     **/
    public EnvPlotter(BoundedEnv env, EnvPlotterGUI disp)
    {
        configure(env, disp);
    }

    /** Constructs an object that draws in the specified environment.
     *      @param env the environment in which to draw
     *      @param disp an object that knows how to display an environment
     **/
    public void configure(BoundedEnv env, EnvPlotterGUI disp)
    {
        theEnv = env;
        display = disp;
    }

  // drawing methods

    /** Removes all objects from the environment.
     **/
    public void clearEnv()
    {
        System.out.println("The method for clearing the environment " +
                           "has not been fully implemented yet.");

        // CODE MISSING !
        //     Should call ensureEmpty for every location in the environment.

        // Display the environment after it has been completely cleared.
        display.showEnv();
    }

    /** Fills in all the cells of the environment using a row-major
     *  traversal.
     *      @param  color the color to use when filling in cells
     **/
    public void rowMajorFill(Color color)
    {
        for ( int row = 0; row < theEnv.numRows(); row++ )
        {
            for ( int column = 0; column < theEnv.numCols(); column++ )
            {
                placeColorBlock(color, row, column);
            }
        }
    }

    /** Fills in all the cells of the environment using a column-major
     *  traversal.
     *      @param  color the color to use when filling in cells
     **/
    public void colMajorFill(Color color)
    {
        System.out.println("The method for column-major traversals " +
                           "has not been implemented yet.");
    }

  // helper methods that are called by other methods

    /** Ensures that the specified location is empty by removing the object
     *  there, if there is one.
     *      @param row      row number of location that should be empty
     *      @param column   column number of location that should be empty
     **/
    private void ensureEmpty(int row, int column)
    {
        // If the specified location in the environment is not empty,
        // remove whatever object is there.
        Location loc = new Location(row, column);
        if ( ! theEnv.isEmpty(loc) )
            theEnv.remove(theEnv.objectAt(loc));
    }

    /** Puts a color block of the specified color in the specified location
     *  and redisplays the environment.
     *      @param color    color to use when placing a color block
     *      @param row      row in which to place the new color block
     *      @param column   column in which to place the new color block
     **/
    private void placeColorBlock(Color color, int row, int column)
    {
        // First remove any color block that happens to be at this location.
        ensureEmpty(row, column);

        // Construct the color block, which adds itself to the environment.
        // Then display the environment.
        Location loc = new Location(row, column);
        new ColorBlock(color, theEnv, loc);
        display.showEnv();
    }

}
